@@ -10,6 +10,16 @@ current_project_context: ContextVar[Optional[str]] = ContextVar(
     "current_project", default=None
 )
 
+# Context variable to store the current log color
+current_log_color: ContextVar[Optional[str]] = ContextVar(
+    "current_log_color", default=None
+)
+
+# Context variable to store the current log format
+current_format: ContextVar[Optional[str]] = ContextVar(
+    "current_format", default="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+)
+
 
 class ShortNameFormatter(logging.Formatter):
     """Custom formatter that shows only the class name instead of full module path."""
@@ -20,10 +30,36 @@ class ShortNameFormatter(logging.Formatter):
             record.name = record.name.split(".")[-1]
 
         # Add project field - use context if not explicitly set
+        project_value = current_project_context.get() or ""
         if not hasattr(record, "project"):
-            record.project = current_project_context.get() or ""
+            record.project = project_value
 
-        return super().format(record)
+        # Get the log color from context if available
+        log_color = getattr(record, "log_color", None) or current_log_color.get()
+
+        # Get the current format from context and update the formatter
+        # If no specific format is set, determine format based on project context
+        current_fmt = current_format.get()
+        if current_fmt is None:
+            if project_value:
+                current_fmt = (
+                    "%(asctime)s - %(name)s - %(project)s - %(levelname)s - %(message)s"
+                )
+            else:
+                current_fmt = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+
+        if current_fmt and current_fmt != self._style._fmt:
+            self._style._fmt = current_fmt
+
+        # Format the message with the parent formatter
+        formatted_message = super().format(record)
+
+        # Apply color if available
+        if log_color:
+            reset_color = "\033[0m"
+            return f"{log_color}{formatted_message}{reset_color}"
+
+        return formatted_message
 
 
 def get_logger(
@@ -53,26 +89,24 @@ def get_logger(
         # Let the logger inherit from root logger (which is configured by configure_logging)
         logger.setLevel(logging.NOTSET)
 
-    # Propagate to parent loggers (root logger) to use basicConfig
-    # since we're using basicConfig for root logging
-    logger.propagate = True  # Let root logger handle it
+    # Always use our custom formatter to ensure colors work
+    if format_string is None:
+        format_string = current_format.get()
 
-    # Only add handler if we want a custom format different from root
-    if format_string is not None:
-        # Create console handler
-        handler = logging.StreamHandler(sys.stdout)
-        handler_level = level if level is not None else logger.getEffectiveLevel()
-        handler.setLevel(handler_level)
+    # Create console handler
+    handler = logging.StreamHandler(sys.stdout)
+    handler_level = level if level is not None else logger.getEffectiveLevel()
+    handler.setLevel(handler_level)
 
-        # Create formatter with our custom short name formatter
-        formatter = ShortNameFormatter(format_string)
-        handler.setFormatter(formatter)
+    # Create formatter with our custom short name formatter
+    formatter = ShortNameFormatter(format_string)
+    handler.setFormatter(formatter)
 
-        # Add handler to logger
-        logger.addHandler(handler)
+    # Add handler to logger
+    logger.addHandler(handler)
 
-        # Disable propagation since we have our own handler
-        logger.propagate = False
+    # Disable propagation since we have our own handler
+    logger.propagate = False
 
     return logger
 
@@ -85,11 +119,30 @@ def set_project_context(project_path: Optional[str]) -> None:
         project_path: The project path to set in context
     """
     current_project_context.set(str(project_path) if project_path else "")
+    current_format.set(
+        "%(asctime)s - %(name)s - %(project)s - %(levelname)s - %(message)s"
+    )
 
 
 def clear_project_context() -> None:
     """Clear the current project context."""
     current_project_context.set("")
+    current_format.set("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+
+
+def set_log_color(log_color: Optional[str]) -> None:
+    """
+    Set the current log color for logging.
+
+    Args:
+        log_color: The ANSI color code to set for logs
+    """
+    current_log_color.set(log_color)
+
+
+def clear_log_color() -> None:
+    """Clear the current log color."""
+    current_log_color.set(None)
 
 
 def configure_logging(verbose: bool = False) -> None:
@@ -110,33 +163,10 @@ def configure_logging(verbose: bool = False) -> None:
     handler.setLevel(level)
 
     # Use our custom formatter that shows only class names
-    formatter = ShortNameFormatter(
-        "%(asctime)s - %(name)s - %(project)s - %(levelname)s - %(message)s"
-    )
+    formatter = ShortNameFormatter(current_format.get())
+
     handler.setFormatter(formatter)
 
     # Configure root logger
     root_logger.setLevel(level)
     root_logger.addHandler(handler)
-
-
-def log_with_project(
-    logger: logging.Logger, level: int, msg: str, project_path: Optional[str] = None
-) -> None:
-    """
-    Log a message with project information.
-
-    Args:
-        logger: The logger instance
-        level: Logging level (e.g., logging.INFO)
-        msg: The message to log
-        project_path: Optional project path to include in the log
-    """
-    # Create a log record
-    record = logger.makeRecord(logger.name, level, "", 0, msg, (), None)
-
-    # Add project information
-    record.project = str(project_path) if project_path else ""
-
-    # Handle the record
-    logger.handle(record)
